#!/bin/bash
### Script to get sounding and surface points for validation purposes

scratch='false'

# Input folder
infolder='/ccc/scratch/cont003/lmd/fitaborl/estudios/FPS_ALPS/additional/IOP'

# Domain
domn='02'

# Output folder
ofolder='/ccc/scratch/cont003/lmd/fitaborl/estudios/FPS_ALPS/additional/IOP/validation'

# Labels of the experiments
experiments='120lev:80lev:50lev:50lev_assigned:38lev:NOaerosol'

# Sounding stations [sndid],[sndlon],[sndlat]:[sndid2],[sndlon2],[sndlat2]:...
sndstations='10868,11.55,48.25:16080,9.28,45.43:16144,11.61,44.65:16546,8.85,39.35'

# Surface stations [sfcid],[sfclon],[sfclat]:[sfcid2],[sfclon2],[sfclat2]:...
sfcstations='None'

# Sounding diagnostics
snddiags='WRFt:WRFtda:WRFp:WRFua:WRFva:ws:WRFwd'

# Surface diagnostics
sfcdiags='wds:wss:WRFtdas:pr'

# Surface NON-diag variables
sfcnondiags='T2'

# cdx Surface diagnostics
cdxdiags='None'

# cdx Surface NON-diag variables
cdxnondiags='PR:PRW:PSL:UAS:VAS:CAPEMAX:CAPEMEAN:CINMAX:CINMEAN:LFCPMAX:LFCPMEAN:LFCZMAX:LFCZMEAN:LIMAX:LIMEAN'

#######    #######
## MAIN
    #######
errmsg='ERROR -- error -- ERROR -- error'

insoutf='allins_functions.inf'
module load python/2.7.14

exps=`echo ${experiments} | tr ':' ' '`
sndsts=`echo ${sndstations} | tr ':' ' '`
sfcsts=`echo ${sfcstations} | tr ':' ' '`

for expn in ${exps}; do
  ifold=${infolder}/${expn}/wrfout
  ofold=${ofolder}/${expn}

  mkdir -p ${ofold}

  if test ! ${sndstations} = 'None'; then
  for sndvn in ${sndsts}; do
    sndid=`echo ${sndvn} | tr ',' ' ' | awk '{print $1}'`
    sndlon=`echo ${sndvn} | tr ',' ' ' | awk '{print $2}'`
    sndlat=`echo ${sndvn} | tr ',' ' ' | awk '{print $3}'`

    kout='snd'
    filek='_vars_'${kout}'pt _'${kout}'diags'
    # Sounding values
    if test ! ${snddiags} = 'None'; then
      fHEADn='simout'
      files=`ls -1 ${infolder}/${expn}/wrfout/wrfout_d${domn}*`
      ofile=${ofold}/${fHEADn}_${kout}diags_${sndid}_${expn}.nc
      if test ${scratch} = 'true'; then rm ${ofile} >& /dev/null; fi
      if test ! -f ${ofile}; then
        for filen in ${files}; do
          $pyHOME/get_WRFsounding-surface_data.bash ${scratch} ${ofold} ${expn}      \
            ${sndvn} None ${filen} ${snddiags},None,None,None,None
        # end of files
        done

       # Concatenating files
        values=${ofold}',Time,time'
        for fk in ${filek}; do
          ofile=${ofold}/${fHEADn}${fk}_${sndid}_${expn}.nc
          HMT=${fHEADn}${fk}'_,'${sndid}'_'${expn},'nc'
          Nfiles=`ls -1 ${ofold}/${fHEADn}${fk}_*${sndid}_${expn}*.nc | wc -l`
          if test ${Nfiles} -gt 1; then
            python ${pyHOME}/nc_var.py -o netcdf_fold_concatenation_HMT -S ${values} \
             -f ${HMT} -v all
            if test $? -ne 0; then
              echo ${errmsg}
              echo "  python failed!!"
              echo python ${pyHOME}/nc_var.py -o netcdf_fold_concatenation_HMT           \
              -S ${values} -f ${HMT} -v all
              exit
            fi
            echo " * Concatenating sounding data '"${fk}"' at point: "${sndid} >> ${insoutf}
            echo python  ${pyHOME}/nc_var.py -o netcdf_fold_concatenation_HMT            \
             -S "'"${values}"'" -f ${HMT} -v all >> ${insoutf}
            echo " " >> ${insoutf}
            mv netcdf_fold_concatenated_HMT.nc ${ofile}
            rm ${ofold}/${fHEADn}${fk}_${sndid}_${expn}_????-??-??_??:??:??.nc >& /dev/null
          else
            file1=`ls -1 ${ofold}/${fHEADn}${fk}_*${sndid}_${expn}*.nc`
            mv ${file1} ${ofile}
          fi
        done
      fi
     fi

    # cordex values
    if test ! ${cdxdiags} = 'None' || test ! ${cdxnondiags} = 'None'; then
      fHEADn='simcdx'
      files=`ls -1 ${infolder}/${expn}/wrfout/wrfcdx_d${domn}*`
      ofile=${ofold}/${fHEADn}_${kout}diags_${sndid}_${expn}.nc
      if test ${scratch} = 'true'; then rm ${ofile} >& /dev/null; fi
      if test ! -f ${ofile}; then
        for filen in ${files}; do
          $pyHOME/get_WRFsounding-surface_data.bash ${scratch} ${ofold} ${expn}      \
            ${sndvn} None ${filen} None,None,None,${cdxdiags},${cdxnondiags}
        # end of files
        done

        # Concatenating files
        values=${ofold}',Time,time'
        for fk in ${filek}; do
          ofile=${ofold}/${fHEADn}${fk}_${sndid}_${expn}.nc
          HMT=${fHEADn}${fk}'_,'${sndid}'_'${expn},'nc'
          Nfiles=`ls -1 ${ofold}/${fHEADn}${fk}_*${sndid}_${expn}*.nc | wc -l`
          if test ${Nfiles} -gt 1; then
            python ${pyHOME}/nc_var.py -o netcdf_fold_concatenation_HMT -S ${values}   \
             -f ${HMT} -v all
            if test $? -ne 0; then
              echo ${errmsg}
              echo "  python failed!!"
              echo python ${pyHOME}/nc_var.py -o netcdf_fold_concatenation_HMT         \
                -S ${values} -f ${HMT} -v all
              exit
            fi
            echo " * Concatenating cdx sounding data at point: "${sndlon}", "${sndlat} >>\
              ${insoutf}
            echo python  ${pyHOME}/nc_var.py -o netcdf_fold_concatenation_HMT          \
             -S "'"${values}"'" -f ${HMT} -v all >> ${insoutf}
            echo " " >> ${insoutf}
            mv netcdf_fold_concatenated_HMT.nc ${ofile}
            rm ${ofold}/${fHEADn}${fk}_${sndid}_${expn}_????-??-??_??:??:??.nc >& /dev/null
          else
            file1=`ls -1 ${ofold}/${fHEADn}${fk}_*${sndid}_${expn}*.nc`
            mv ${file1} ${ofile}
          fi
        done
      fi
     fi
  # end of sounding stations
  done
  fi

  # Surface stations
  if test ! ${sfcstations} = 'None'; then
  for sfcvn in ${sfcsts}; do
    sfcid=`echo ${sfcvn} | tr ',' ' ' | awk '{print $1}'`
    sfclon=`echo ${sfcvn} | tr ',' ' ' | awk '{print $2}'`
    sfclat=`echo ${sfcvn} | tr ',' ' ' | awk '{print $3}'`

    kout='sfc'
    filek='_vars_'${kout}'pt _'${kout}'diags'
    # out sfc pt
    if test ! ${sfcdiags} = 'None' || test ! ${sfcnondiags} = 'None'; then
      fHEADn='simout'
      files=`ls -1 ${infolder}/${expn}/wrfout/wrfout_d${domn}*`
      ofile=${ofold}/${fHEADn}_${kout}diags_${sfcid}_${expn}.nc
      if test ${scratch} = 'true'; then rm ${ofile} >& /dev/null; fi
      if test ! -f ${ofile}; then
        for filen in ${files}; do
          $pyHOME/get_WRFsounding-surface_data.bash ${scratch} ${ofold} ${expn} None \
            ${sfcvn} ${filen} None,${sfcdiags},${sfcnondiags},None,None
        # end of files
        done

        # Concatenating files
        values=${ofold}',Time,time'
        for fk in ${filek}; do
          ofile=${ofold}/${fHEADn}${fk}_${sfcid}_${expn}.nc
          HMT=${fHEADn}${fk}'_,'${sfcid}'_'${expn},'nc'
          Nfiles=`ls -1 ${ofold}/${fHEADn}${fk}_*${sfcid}_${expn}*.nc | wc -l`
          if test ${Nfiles} -gt 0; then
            python ${pyHOME}/nc_var.py -o netcdf_fold_concatenation_HMT -S ${values}   \
             -f ${HMT} -v all
            if test $? -ne 0; then
              echo ${errmsg}
              echo "  python failed!!"
              echo python ${pyHOME}/nc_var.py -o netcdf_fold_concatenation_HMT         \
                -S ${values} -f ${HMT} -v all
              exit
            fi
            echo " * Concatenating surface data '"${fk}"' at point: "${sfcid} >> ${insoutf}
            echo python  ${pyHOME}/nc_var.py -o netcdf_fold_concatenation_HMT          \
             -S "'"${values}"'" -f ${HMT} -v all >> ${insoutf}
            echo " " >> ${insoutf}
            mv netcdf_fold_concatenated_HMT.nc ${ofile}
            rm ${ofold}/${fHEADn}${fk}_${sfcid}_${expn}_????-??-??_??:??:??.nc >& /dev/null
          else
            file1=`ls -1 ${ofold}/${fHEADn}${fk}_*${sfcid}_${expn}*.nc`
            mv ${file1} ${ofile}
          fi
        done
      fi
    fi

    # cdx sfc pt
    if test ! ${cdxdiags} = 'None' || test ! ${cdxnondiags} = 'None'; then
      fHEADn='simcdx'
      files=`ls -1 ${infolder}/${expn}/wrfout/wrfcdx_d${domn}*`
      ofile=${ofold}/${fHEADn}_${kout}diags_${sfcid}_${expn}.nc
      if test ${scratch} = 'true'; then rm ${ofile} >& /dev/null; fi
      if test ! -f ${ofile}; then
        for filen in ${files}; do
          $pyHOME/get_WRFsounding-surface_data.bash ${scratch} ${ofold} ${expn} None \
            ${sfcvn} ${filen} None,None,None,${cdxdiags},${cdxnondiags}
        # end of files
        done

        # Concatenating files
        values=${ofold}',Time,time'
        for fk in ${filek}; do
          ofile=${ofold}/${fHEADn}${fk}_${sfcid}_${expn}.nc
          HMT=${fHEADn}${fk}'_,'${sfcid}'_'${expn},'nc'
          Nfiles=`ls -1 ${ofold}/${fHEADn}${fk}_*${sfcid}_${expn}*.nc | wc -l`
          if test ${Nfiles} -gt 0; then
            python ${pyHOME}/nc_var.py -o netcdf_fold_concatenation_HMT -S ${values}   \
             -f ${HMT} -v all
            if test $? -ne 0; then
              echo ${errmsg}
              echo "  python failed!!"
              echo python ${pyHOME}/nc_var.py -o netcdf_fold_concatenation_HMT         \
                -S ${values} -f ${HMT} -v all
              exit
            fi
            echo " * Concatenating cdx surface data at point: "${sfcid} >> ${insoutf}
            echo python  ${pyHOME}/nc_var.py -o netcdf_fold_concatenation_HMT          \
             -S "'"${values}"'" -f ${HMT} -v all >> ${insoutf}
            echo " " >> ${insoutf}
            mv netcdf_fold_concatenated_HMT.nc ${ofile}
            rm ${ofold}/${fHEADn}${fk}_${sfcid}_${expn}_????-??-??_??:??:??.nc >& /dev/null
          else
            file1=`ls -1 ${ofold}/${fHEADn}${fk}_*${sfcid}_${expn}*.nc`
            mv ${file1} ${ofile}
          fi
        done
      fi
      #exit
    fi

  # end of surfaces
  done
  fi

  # 2D maps
  kout='sfcmap'
  filek='_vars_'${kout}' _'${kout}'diags'
  okind='out cdx' 
  for ik in ${okind}; do
    fHEADn='sim'${ik}
    for fk in ${filek}; do
      ofile=${ofold}/${fHEADn}${fk}_${expn}.nc
      if test ${scratch} = 'true'; then rm ${ofile} >& /dev/null; fi
      if test ! -f ${ofile}; then
        # Concatenating files
        values=${ofold}',Time,time'
        HMT=${fHEADn}${fk}'_,'${expn},'nc'
        Nfiles=`ls -1 ${ofold}/${fHEADn}${fk}_*${expn}*.nc | wc -l`
        if test ${Nfiles} -gt 0; then
          python ${pyHOME}/nc_var.py -o netcdf_fold_concatenation_HMT -S ${values}     \
           -f ${HMT} -v all
          if test $? -ne 0; then
            echo ${errmsg}
            echo "  python failed!!"
            echo python ${pyHOME}/nc_var.py -o netcdf_fold_concatenation_HMT           \
              -S ${values} -f ${HMT} -v all
            exit
          fi
          echo " * Concatenating '${ik}' surface map data: " >> ${insoutf}
          echo python  ${pyHOME}/nc_var.py -o netcdf_fold_concatenation_HMT            \
           -S "'"${values}"'" -f ${HMT} -v all >> ${insoutf}
          echo " " >> ${insoutf}
          mv netcdf_fold_concatenated_HMT.nc ${ofile}
          rm ${ofold}/${fHEADn}${fk}_${expn}_????-??-??_??:??:??.nc >& /dev/null
        else
          file1=`ls -1 ${ofold}/${fHEADn}${fk}_*${expn}*.nc`
          mv ${file1} ${ofile}
        fi
      fi
    done
  done

# End of experiments
done
